diff finch/gntconn.c @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 0e3a8505ebbe
children 66dff3dfdea6
line wrap: on
line diff
--- a/finch/gntconn.c	Mon Mar 19 06:11:46 2007 +0000
+++ b/finch/gntconn.c	Mon Mar 19 07:01:17 2007 +0000
@@ -2,9 +2,9 @@
  * @file gntconn.c GNT Connection API
  * @ingroup gntui
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -27,33 +27,33 @@
 #include "request.h"
 
 #include "gntconn.h"
-#include "gntgaim.h"
+#include "finch.h"
 
 static void
-finch_connection_report_disconnect(GaimConnection *gc, const char *text)
+finch_connection_report_disconnect(PurpleConnection *gc, const char *text)
 {
 	char *act, *primary, *secondary;
-	GaimAccount *account = gaim_connection_get_account(gc);
+	PurpleAccount *account = purple_connection_get_account(gc);
 
-	act = g_strdup_printf(_("%s (%s)"), gaim_account_get_username(account),
-			gaim_account_get_protocol_name(account));
+	act = g_strdup_printf(_("%s (%s)"), purple_account_get_username(account),
+			purple_account_get_protocol_name(account));
 
 	primary = g_strdup_printf(_("%s disconnected."), act);
 	secondary = g_strdup_printf(_("%s was disconnected due to the following error:\n%s"),
 			act, text);
 
-	gaim_request_action(account, _("Connection Error"), primary, secondary, 1,
+	purple_request_action(account, _("Connection Error"), primary, secondary, 1,
 						account, 2,
 						_("OK"), NULL,
 						_("Connect"),
-						GAIM_CALLBACK(gaim_account_connect));
+						PURPLE_CALLBACK(purple_account_connect));
 
 	g_free(act);
 	g_free(primary);
 	g_free(secondary);
 }
 
-static GaimConnectionUiOps ops = 
+static PurpleConnectionUiOps ops = 
 {
 	.connect_progress = NULL,
 	.connected = NULL,
@@ -62,7 +62,7 @@
 	.report_disconnect = finch_connection_report_disconnect
 };
 
-GaimConnectionUiOps *finch_connections_get_ui_ops()
+PurpleConnectionUiOps *finch_connections_get_ui_ops()
 {
 	return &ops;
 }
@@ -2,9 +2,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.